@@ -68,6 +68,57 @@ const fluentConfTemplate = `{{- define "fluentConf" -}}
 {{ . }}
 {{- end}}
 
+<label @MEASURE>
+  <filter **>
+    @type record_transformer
+    enable_ruby
+    <record>
+      msg_size ${record.to_s.length}
+    </record>
+  </filter>
+  <filter **>
+    @type prometheus
+    <metric>
+      name cluster_logging_collector_input_record_total
+      type counter
+      desc The total number of incoming records
+      <labels>
+        tag ${tag}
+        hostname ${hostname}
+      </labels>
+    </metric>
+  </filter>
+  <filter **>
+    @type prometheus
+    <metric>
+      name cluster_logging_collector_input_record_bytes
+      type counter
+      desc The total bytes of incoming records
+      key msg_size
+      <labels>
+        tag ${tag}
+        hostname ${hostname}
+      </labels>
+    </metric>
+  </filter>
+  <filter **>
+    @type record_transformer
+    remove_keys msg_size
+  </filter>
+  <match journal>
+    @type relabel
+    @label @INGRESS
+  </match>
+  <match *audit.log>
+    @type relabel
+    @label @INGRESS
+   </match>
+  <match kubernetes.**>
+    @type relabel
+    @label @CONCAT
+  </match>
+</label>
+
 <label @CONCAT>
   <filter kubernetes.**>
     @type concat
@@ -387,7 +438,7 @@ const inputSourceJournalTemplate = `{{- define "inputSourceJournalTemplate" -}}
 <source>
   @type systemd
   @id systemd-input
-  @label @INGRESS
+  @label @MEASURE
   path '/var/log/journal'
   <storage>
     @type local
@@ -414,7 +465,7 @@ const inputSourceContainerTemplate = `{{- define "inputSourceContainerTemplate"
   rotate_wait 5
   tag kubernetes.*
   read_from_head "true"
-  @label @CONCAT
+  @label @MEASURE
   <parse>
     @type multi_format
     <pattern>
@@ -437,7 +488,7 @@ const inputSourceHostAuditTemplate = `{{- define "inputSourceHostAuditTemplate"
 <source>
   @type tail
   @id audit-input
-  @label @INGRESS
+  @label @MEASURE
   path "#{ENV['AUDIT_FILE'] || '/var/log/audit/audit.log'}"
   pos_file "#{ENV['AUDIT_POS_FILE'] || '/var/log/audit/audit.log.pos'}"
   tag linux-audit.log
@@ -452,7 +503,7 @@ const inputSourceK8sAuditTemplate = `{{- define "inputSourceK8sAuditTemplate" -}
 <source>
   @type tail
   @id k8s-audit-input
-  @label @INGRESS
+  @label @MEASURE
   path "#{ENV['K8S_AUDIT_FILE'] || '/var/log/kube-apiserver/audit.log'}"
   pos_file "#{ENV['K8S_AUDIT_POS_FILE'] || '/var/log/kube-apiserver/audit.log.pos'}"
   tag k8s-audit.log
@@ -471,7 +522,7 @@ const inputSourceOpenShiftAuditTemplate = `{{- define "inputSourceOpenShiftAudit
 <source>
   @type tail
   @id openshift-audit-input
-  @label @INGRESS
+  @label @MEASURE
   path /var/log/oauth-apiserver/audit.log,/var/log/openshift-apiserver/audit.log
   pos_file /var/log/oauth-apiserver.audit.log
   tag openshift-audit.log
@@ -646,8 +697,6 @@ const storeElasticsearchTemplate = `{{ define "storeElasticsearch" -}}
   target_index_key viaq_index_name
   id_key viaq_msg_id
   remove_keys viaq_index_name
-  user fluentd
-  password changeme
 {{- if .Target.Secret }}
   client_key '{{ .SecretPath "tls.key"}}'
   client_cert '{{ .SecretPath "tls.crt"}}'
